%
% Function which plot iteration of golden section minimization
%
%  fun = function used by the secant methd
%  Iab = vector with interval history
%
function goldenPlotIteration( fun, Iab )
  lw = {'-ko','-ro'} ;
  fc = {'y', 'g' } ;
  
  % evaluate X range
  xmin = Iab(1,1) ;
  xmax = Iab(1,2) ;

  % enlarge a bit the range for aestetical reason
  len  = xmax-xmin ;
  xmin = xmin - len/10 ;
  xmax = xmax + len/10 ;
  
  % sampling of the function for plotting
  XX   = [xmin:len/1000:xmax] ;
  YY   = feval(fun,XX) ;

  % evaluate y bounding box of the function
  ymin = min(YY) ;
  ymax = max(YY) ;
  
  % plot function
  plot(XX,YY,'g-','LineWidth',1.1);
  hold on;

  plot([xmin;xmax],[0;0],'k-','LineWidth',1);
  
  ii = 2 ;
  for i=1:size(Iab,1)
    ii = 3-ii ;
    z  = -i/2 ;
    plot([Iab(i,1);Iab(i,2)],[z;z],...
         lw{ii},'LineWidth',1, ...
         'MarkerEdgeColor','k', ...
         'MarkerFaceColor',fc{ii},...
         'MarkerSize',6 ...
         );
    plot([Iab(i,3);Iab(i,4)],[z;z],'or','MarkerSize',4);
  end
  
  axis on ;
  hold off;
end
